@@ -1,4 +1,5 @@
 from .bufferobject import BufferObject
+from compas.utilities import pairwise
 
 
 class PolylineObject(BufferObject):
@@ -7,10 +8,11 @@ class PolylineObject(BufferObject):
     default_color_points = [0.1, 0.1, 0.1]
     default_color_line = [0.4, 0.4, 0.4]
 
-    def __init__(self, data, pointcolor=None, linecolor=None, color=None, **kwargs):
+    def __init__(self, data, close=False, pointcolor=None, linecolor=None, color=None, **kwargs):
         super().__init__(data, show_lines=True, **kwargs)
         self.pointcolor = pointcolor or color
         self.linecolor = linecolor or color
+        self.close = close
 
     def _points_data(self):
         polyline = self._data
@@ -26,10 +28,16 @@ class PolylineObject(BufferObject):
         positions = []
         colors = []
         elements = []
-        for i in range(len(polyline.points)-1):
-            positions.append(list(polyline.points[i]))
-            positions.append(list(polyline.points[i+1]))
+        if self.close:
+            lines = pairwise(polyline.points + [polyline.points[0]])
+        else:
+            lines = pairwise(polyline.points)
+        count = 0
+        for pt1, pt2 in lines:
+            positions.append(pt1)
+            positions.append(pt2)
             colors.append(color)
             colors.append(color)
-            elements.append([i*2, i*2+1])
+            elements.append([count, count+1])
+            count += 2
         return positions, colors, elements
